"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@code-engine/utils");
const error_1 = require("./error");
const file_1 = require("./file");
/**
 * Returns a cloneable copy of the given run object.
 * @internal
 */
function cloneRun(run) {
    // tslint:disable-next-line: no-object-literal-type-assertion
    let clone = { ...run, log: undefined };
    clone.changedFiles = run.changedFiles.map(file_1.cloneChangedFile);
    return clone;
}
exports.cloneRun = cloneRun;
/**
 * Creates a `Run` object from a `RunClone`.
 * @internal
 */
function createRun(messenger, messageId, run) {
    return {
        ...run,
        changedFiles: run.changedFiles.map((file) => utils_1.createChangedFile(file)),
        log: createLogger(messenger, messageId, run),
    };
}
exports.createRun = createRun;
/**
 * Creates a `Logger` object from a `RunClone`.
 */
function createLogger(messenger, messageId, run) {
    function log(message, data) {
        if (typeof message === "string") {
            log.info(message, data);
        }
        else {
            log.error(message, data);
        }
    }
    log.info = (message, data) => {
        messenger.postReply(createLogReply("info" /* Info */, messageId, message, data));
    };
    log.debug = (message, data) => {
        if (run.debug) {
            messenger.postReply(createLogReply("debug" /* Debug */, messageId, message, data));
        }
    };
    log.warn = (warning, data) => {
        messenger.postReply(createLogReply("warning" /* Warning */, messageId, warning, data));
    };
    log.error = (error, data) => {
        messenger.postReply(createLogReply("error" /* Error */, messageId, error, data));
    };
    return log;
}
function createLogReply(level, to, msg, data) {
    let message = error_1.cloneError(msg);
    return { type: "log", to, level, message, data };
}
//# sourceMappingURL=run.js.map