import { Cloneable, CodeEngine, FileProcessor } from "@code-engine/types";
/**
 * Runs CodeEngine plugins on worker threads.
 */
export declare class WorkerPool {
    constructor(engine: CodeEngine);
    /**
     * Indicates the number of worker threads in the pool.
     */
    get size(): number;
    /**
     * Indicates whether the `dispose()` method has been called.
     * Once disposed, the `WorkerPool` instance is no longer usable.
     */
    get isDisposed(): boolean;
    /**
     * Imports the specified `FileProcessor` module in all worker threads.
     *
     * @returns - A proxy function that executes the processor in one of the threads.
     */
    importFileProcessor(moduleId: string, data?: Cloneable): Promise<FileProcessor>;
    /**
     * Imports the specified JavaScript module in all worker threads.
     */
    importModule(moduleId: string, data?: Cloneable): Promise<void>;
    /**
     * Terminates all worker threads.
     */
    dispose(): Promise<void>;
}
