"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const error_1 = require("../clone/error");
/**
 * Allows an `Executor` to handle and reply to messages from a `Worker`.
 * @internal
 */
class Messenger {
    constructor(port) {
        this._port = port;
        port.on("message", this._handleMessage.bind(this));
    }
    /**
     * Replies to a message from the `Worker`.
     */
    postReply(reply, transferList) {
        this._port.postMessage(reply, transferList);
    }
    /**
     * Handles incoming messages from the `Worker`.
     */
    async _handleMessage(message) {
        try {
            // tslint:disable-next-line: switch-default
            switch (message.type) {
                case "importFileProcessor":
                    await this.importFileProcessor(message);
                    break;
                case "importModule":
                    await this.importModule(message);
                    break;
                case "processFile":
                    await this.processFile(message);
                    break;
            }
        }
        catch (error) {
            // Something went wrong while handling the message, so reply with an error.
            this.postReply({ to: message.id, type: "error", error: error_1.cloneError(error) });
        }
    }
}
exports.Messenger = Messenger;
//# sourceMappingURL=messenger.js.map